"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AzureLoginController = void 0;
const tslib_1 = require("tslib");
const core_1 = require("@loopback/core");
const repository_1 = require("@loopback/repository");
const rest_1 = require("@loopback/rest");
const core_2 = require("@sourceloop/core");
const loopback4_authentication_1 = require("loopback4-authentication");
const loopback4_authorization_1 = require("loopback4-authorization");
const providers_1 = require("../../providers");
const repositories_1 = require("../../repositories");
const client_auth_request_dto_1 = require("./models/client-auth-request.dto");
const token_response_dto_1 = require("./models/token-response.dto");
const queryGen = (from) => {
    return (req) => {
        return {
            customState: `client_id=${req[from].client_id}`,
        };
    };
};
const offSet = 10;
let AzureLoginController = class AzureLoginController {
    constructor(authClientRepository, logger, getAuthCode) {
        this.authClientRepository = authClientRepository;
        this.logger = logger;
        this.getAuthCode = getAuthCode;
    }
    async getLoginViaAzure(clientId, //NOSONAR
    clientSecret) {
        //do nothing
    }
    async postLoginViaAzure(clientCreds) {
        //do nothing
    }
    async azureCallback(code, //NOSONAR
    state, sessionState, //NOSONAR
    response, user) {
        var _a;
        const clientId = state.substring(state.indexOf('client_id=') + offSet);
        if (!clientId || !user) {
            throw new rest_1.HttpErrors.Unauthorized("Client Invalid" /* AuthErrorKeys.ClientInvalid */);
        }
        const client = await this.authClientRepository.findOne({
            where: {
                clientId,
            },
        });
        if (!client || !client.redirectUrl) {
            throw new rest_1.HttpErrors.Unauthorized("Client Invalid" /* AuthErrorKeys.ClientInvalid */);
        }
        try {
            const token = await this.getAuthCode(client, user);
            const role = user.role;
            response.redirect(`${(_a = process.env.WEBAPP_URL) !== null && _a !== void 0 ? _a : ''}${client.redirectUrl}?code=${token}&role=${role}`);
        }
        catch (error) {
            this.logger.error(error);
            throw new rest_1.HttpErrors.Unauthorized("Invalid Credentials" /* AuthErrorKeys.InvalidCredentials */);
        }
    }
};
tslib_1.__decorate([
    (0, loopback4_authentication_1.authenticateClient)("client-password" /* STRATEGY.CLIENT_PASSWORD */),
    (0, loopback4_authentication_1.authenticate)("Azure AD" /* STRATEGY.AZURE_AD */, {
        scope: ['profile', 'email', 'openid', 'offline_access'],
        identityMetadata: process.env.AZURE_IDENTITY_METADATA,
        clientID: process.env.AZURE_AUTH_CLIENT_ID,
        responseType: 'code',
        responseMode: 'query',
        redirectUrl: process.env.AZURE_AUTH_REDIRECT_URL,
        clientSecret: process.env.AZURE_AUTH_CLIENT_SECRET,
        allowHttpForRedirectUrl: !!process.env.AZURE_AUTH_ALLOW_HTTP_REDIRECT,
        passReqToCallback: !!process.env.AZURE_AUTH_PASS_REQ_CALLBACK,
        validateIssuer: !!process.env.AZURE_AUTH_VALIDATE_ISSUER,
        useCookieInsteadOfSession: !!process.env.AZURE_AUTH_COOKIE_INSTEAD_SESSION,
        cookieEncryptionKeys: [
            {
                key: process.env.AZURE_AUTH_COOKIE_KEY,
                iv: process.env.AZURE_AUTH_COOKIE_IV,
            },
        ],
    }, queryGen('query')),
    (0, loopback4_authorization_1.authorize)({ permissions: ['*'] }),
    rest_1.oas.deprecated(),
    (0, rest_1.get)('/auth/azure', {
        description: 'POST Call for azure based login',
        responses: {
            [200 /* STATUS_CODE.OK */]: {
                description: 'Azure Token Response',
                content: {
                    [core_2.CONTENT_TYPE.JSON]: {
                        schema: { [core_2.X_TS_TYPE]: token_response_dto_1.TokenResponse },
                    },
                },
            },
        },
    }),
    tslib_1.__param(0, rest_1.param.query.string('client_id')),
    tslib_1.__param(1, rest_1.param.query.string('client_secret')),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [String, String]),
    tslib_1.__metadata("design:returntype", Promise)
], AzureLoginController.prototype, "getLoginViaAzure", null);
tslib_1.__decorate([
    (0, loopback4_authentication_1.authenticateClient)("client-password" /* STRATEGY.CLIENT_PASSWORD */),
    (0, loopback4_authentication_1.authenticate)("Azure AD" /* STRATEGY.AZURE_AD */, {
        scope: ['profile', 'email', 'openid', 'offline_access'],
        identityMetadata: process.env.AZURE_IDENTITY_METADATA,
        clientID: process.env.AZURE_AUTH_CLIENT_ID,
        responseType: 'code',
        responseMode: 'query',
        redirectUrl: process.env.AZURE_AUTH_REDIRECT_URL,
        clientSecret: process.env.AZURE_AUTH_CLIENT_SECRET,
        allowHttpForRedirectUrl: !process.env.AZURE_AUTH_ALLOW_HTTP_REDIRECT,
        passReqToCallback: !!process.env.AZURE_AUTH_PASS_REQ_CALLBACK,
        validateIssuer: !!process.env.AZURE_AUTH_VALIDATE_ISSUER,
        useCookieInsteadOfSession: !process.env.AZURE_AUTH_COOKIE_INSTEAD_SESSION,
        cookieEncryptionKeys: [
            {
                key: process.env.AZURE_AUTH_COOKIE_KEY,
                iv: process.env.AZURE_AUTH_COOKIE_IV,
            },
        ],
    }, queryGen('body')),
    (0, loopback4_authorization_1.authorize)({ permissions: ['*'] }),
    (0, rest_1.post)('/auth/azure', {
        description: 'POST Call for azure based login',
        responses: {
            [200 /* STATUS_CODE.OK */]: {
                description: 'Azure Token Response',
                content: {
                    [core_2.CONTENT_TYPE.JSON]: {
                        schema: { [core_2.X_TS_TYPE]: token_response_dto_1.TokenResponse },
                    },
                },
            },
        },
    }),
    tslib_1.__param(0, (0, rest_1.requestBody)({
        content: {
            [core_2.CONTENT_TYPE.FORM_URLENCODED]: {
                schema: (0, rest_1.getModelSchemaRef)(client_auth_request_dto_1.ClientAuthRequest),
            },
        },
    })),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [client_auth_request_dto_1.ClientAuthRequest]),
    tslib_1.__metadata("design:returntype", Promise)
], AzureLoginController.prototype, "postLoginViaAzure", null);
tslib_1.__decorate([
    (0, loopback4_authentication_1.authenticate)("Azure AD" /* STRATEGY.AZURE_AD */, {
        scope: ['profile', 'email', 'openid', 'offline_access'],
        identityMetadata: process.env.AZURE_IDENTITY_METADATA,
        clientID: process.env.AZURE_AUTH_CLIENT_ID,
        responseType: 'code',
        responseMode: 'query',
        redirectUrl: process.env.AZURE_AUTH_REDIRECT_URL,
        clientSecret: process.env.AZURE_AUTH_CLIENT_SECRET,
        allowHttpForRedirectUrl: !!process.env.AZURE_AUTH_ALLOW_HTTP_REDIRECT,
        passReqToCallback: !!process.env.AZURE_AUTH_PASS_REQ_CALLBACK,
        validateIssuer: !!process.env.AZURE_AUTH_VALIDATE_ISSUER,
        useCookieInsteadOfSession: !!process.env.AZURE_AUTH_COOKIE_INSTEAD_SESSION,
        cookieEncryptionKeys: [
            {
                key: process.env.AZURE_AUTH_COOKIE_KEY,
                iv: process.env.AZURE_AUTH_COOKIE_IV,
            },
        ],
    }, queryGen('query')),
    (0, loopback4_authorization_1.authorize)({ permissions: ['*'] }),
    (0, rest_1.get)('/auth/azure-oauth-redirect', {
        responses: {
            [200 /* STATUS_CODE.OK */]: {
                description: 'Azure Redirect Token Response',
                content: {
                    [core_2.CONTENT_TYPE.JSON]: {
                        schema: { [core_2.X_TS_TYPE]: token_response_dto_1.TokenResponse },
                    },
                },
            },
        },
    }),
    tslib_1.__param(0, rest_1.param.query.string('code')),
    tslib_1.__param(1, rest_1.param.query.string('state')),
    tslib_1.__param(2, rest_1.param.query.string('session_state')),
    tslib_1.__param(3, (0, core_1.inject)(rest_1.RestBindings.Http.RESPONSE)),
    tslib_1.__param(4, (0, core_1.inject)(loopback4_authentication_1.AuthenticationBindings.CURRENT_USER)),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [String, String, String, Object, Object]),
    tslib_1.__metadata("design:returntype", Promise)
], AzureLoginController.prototype, "azureCallback", null);
AzureLoginController = tslib_1.__decorate([
    tslib_1.__param(0, (0, repository_1.repository)(repositories_1.AuthClientRepository)),
    tslib_1.__param(1, (0, core_1.inject)(core_2.LOGGER.LOGGER_INJECT)),
    tslib_1.__param(2, (0, core_1.inject)(providers_1.AuthCodeBindings.AUTH_CODE_GENERATOR_PROVIDER)),
    tslib_1.__metadata("design:paramtypes", [repositories_1.AuthClientRepository, Object, Function])
], AzureLoginController);
exports.AzureLoginController = AzureLoginController;
//# sourceMappingURL=azure-login.controller.js.map